@@ -237,7 +237,7 @@ class BaseModelMixin:
         return instance
 
     @classmethod
-    def bulk_add(cls, items, with_relationship):
+    def bulk_add(cls, items, with_relationship=False):
         """
         Perform a bulk add of the given list of mapping dictionaries
 
@@ -300,7 +300,7 @@ class BaseModelMixin:
         return instance
 
     @classmethod
-    def batch_update(cls, items, with_relationship):
+    def bulk_update(cls, items, with_relationship=False):
         """
         Perform a bulk update of the given list of mapping dictionaries
         :param items:
@@ -361,7 +361,7 @@ class BaseModelMixin:
         return instance
 
     @classmethod
-    def batch_delete(cls, items):
+    def bulk_delete(cls, items):
         """
         Perform a bulk delete of the given list of mapping dictionaries
 
