@@ -43,7 +43,7 @@ def init_model_rest_blueprint(model_cls, api_blueprint, url_prefix, module, rout
             req_log_data = json.dumps(request_json)
 
             result = model_cls.add(request_json)
-            res_data = model_to_dict(result[1], **to_json_option)
+            res_data = model_to_dict(result[1], to_json_option)
 
             res_log_data = get_log_data(res_data)
             _log_operation(module, 'add', result[0], req_log_data, res_log_data)
@@ -61,7 +61,7 @@ def init_model_rest_blueprint(model_cls, api_blueprint, url_prefix, module, rout
             :return:
             """
             result = model_cls.delete(did)
-            res_data = model_to_dict(result[1], **to_json_option)
+            res_data = model_to_dict(result[1], to_json_option)
 
             res_log_data = get_log_data(res_data)
             _log_operation(module, 'delete', result[0], did, res_log_data)
@@ -82,7 +82,7 @@ def init_model_rest_blueprint(model_cls, api_blueprint, url_prefix, module, rout
             req_log_data = json.dumps(request_json)
 
             result = model_cls.update(request_json)
-            res_data = model_to_dict(result[1], **to_json_option)
+            res_data = model_to_dict(result[1], to_json_option)
 
             res_log_data = get_log_data(res_data)
             _log_operation(module, 'update', result[0], req_log_data, res_log_data)
@@ -109,7 +109,7 @@ def init_model_rest_blueprint(model_cls, api_blueprint, url_prefix, module, rout
                 action = "add"
                 result = model_cls.add(request_json)
 
-            res_data = model_to_dict(result[1], **to_json_option)
+            res_data = model_to_dict(result[1], to_json_option)
             res_log_data = get_log_data(res_data)
             _log_operation(module, action, result[0], req_log_data, res_log_data)
             flaskz_logger.info(get_rest_log_msg('Upsert {} data'.format(class_name), req_log_data, result[0], res_log_data))
@@ -126,7 +126,7 @@ def init_model_rest_blueprint(model_cls, api_blueprint, url_prefix, module, rout
             :return:
             """
             result = model_cls.query_all()
-            res_data = model_to_dict(result[1], **to_json_option)
+            res_data = model_to_dict(result[1], to_json_option)
 
             flaskz_logger.debug(get_rest_log_msg('Query all {} data'.format(class_name), None, result[0], res_data))
             return create_response(result[0], res_data)
@@ -146,7 +146,7 @@ def init_model_rest_blueprint(model_cls, api_blueprint, url_prefix, module, rout
             result = model_cls.query_pss(get_pss(model_cls, request_json))
             res_data = result[1]
             if result[0] is True:
-                res_data['data'] = model_to_dict(res_data['data'], **to_json_option)
+                res_data['data'] = model_to_dict(res_data['data'], to_json_option)
 
             flaskz_logger.debug(get_rest_log_msg('Query pss {} data'.format(class_name), req_log_data, result[0], res_data))
             return create_response(result[0], res_data)
